class FeatureBaseClass(object):

    __feature_name__ = "undefined"

    def __init__(self):
        self.feature = None
        self.trace = None

    def compute(self):
        msg = "compute is not implemented yet"
        raise NotImplementedError(msg)



import pytest

from zizou import FeatureBaseClass

def test_exceptions():
    """
    Test that the right exceptions are raised.
    """
    bc = FeatureBaseClass()
    with pytest.raises(NotImplementedError):
        bc.compute()
